#!/bin/bash
###########################################################################
# lightweight-firewall init script
###########################################################################

###########################################################################
# defs
NAME="lightweight-firewall"
CONFDIR="/etc/$NAME"
PATH="/sbin:/bin:/usr/bin"

###########################################################################
# api
function start {
    # flush all rules
    stop
    # load modules
    for f in $CONFDIR/modules.d/*.mod; do
        if [ -r $f ]; then
            out=`modprobe -a $(< $f) 2>&1`
            if [ -n "$out" ]; then
                log_failure_msg "$f: \"$out\""
            fi
        fi
    done
    # load iptables rules
    for f in $CONFDIR/rules.d/*.rule; do
        if [ -r $f ]; then
            out=`iptables-restore -n < $f 2>&1`
            if [ $? -ne 0 ]; then
                log_failure_msg "$f: \"$out\""
            fi
        fi
    done
}

function stop {
    # flush and delete user chains
    iptables-save | grep -E "^(\*|:)" | while read line; do
        if echo $line | grep -q "^*"; then
            table=`echo $line | cut -c2-`
            iptables -t $table -F
            iptables -t $table -X
        fi
    done
    # change all built-in policies to ACCEPT
    iptables-save | grep -E "^(\*|:)" | while read line; do
        if echo $line | grep -q "^*"; then
            table=`echo $line | cut -c2-`
            continue
        fi
        chain=`echo $line | cut -c2- | cut -d' ' -f1`
        iptables -t $table -P $chain ACCEPT
    done
}

###########################################################################
# main
. /lib/lsb/init-functions

case "$1" in
  start|restart)
    log_begin_msg "Starting $NAME..."
    start
    log_end_msg $?
  ;;

  stop)
    log_begin_msg "Stoping $NAME..."
    stop
    log_end_msg $?
  ;;

  status)
    iptables-save | grep -E -v "^(#|COMMIT)"
  ;;

  *)
    log_failure_msg "Usage: /etc/init.d/$NAME {start|stop|restart|status}"
    exit 1
  ;;
esac

exit 0
